@@ -19,6 +19,7 @@ static const R_CMethodDef CEntries[]  = {
   CALLDEF(cov_MSSD,               5),
   CALLDEF(cov_weighted,           6),
   CALLDEF(cov4th,                 5),
+  CALLDEF(doornik_hansen,         5),
   CALLDEF(dupl_cols,              2),
   CALLDEF(dupl_left_mult,         8),
   CALLDEF(dupl_left_trans,        9),
@@ -31,6 +32,7 @@ static const R_CMethodDef CEntries[]  = {
   CALLDEF(geometric_mean,         3),
   CALLDEF(hadamard_prod,          4),
   CALLDEF(jacobi_solver,          9),
+  CALLDEF(jarque_bera,            5),
   CALLDEF(kronecker_prod,         7),
   CALLDEF(krylov_mat,             8),
   CALLDEF(lu_dcmp,                5),
@@ -47,7 +49,7 @@ static const R_CMethodDef CEntries[]  = {
   CALLDEF(OLS_cg,                 9),
   CALLDEF(OLS_qr,                10),
   CALLDEF(OLS_ridge,             21),
-  CALLDEF(power_method,           9),
+  CALLDEF(power_method,           8),
   CALLDEF(Psi2Q,                  3),
   CALLDEF(seidel_solver,          9),
   CALLDEF(sherman_morrison,       6),
@@ -55,6 +57,7 @@ static const R_CMethodDef CEntries[]  = {
   CALLDEF(svd_dcmp,              11),
   CALLDEF(sweep_operator,         6),
   CALLDEF(symmetrizer_prod,       6),
+  CALLDEF(urzua_ALM,              5),
   CALLDEF(wilson_hilferty_chisq,  4),
   CALLDEF(whitening_chol,         4),
   {NULL, NULL, 0}
